@@ -55,8 +55,9 @@ const int ID_GetToDo             = 35;
 const int ID_GetProductCode      = 36;
 const int ID_AddToDo             = 37;
 const int ID_SetDateTime	 = 38;
+const int ID_DeleteToDo          = 39;
 
-const int ID_Start               = 38; //set it to last value above
+const int ID_Start               = 39; //set it to last value above
 
 class GSM_Device;
 class GSM_AllDevices;
@@ -138,6 +139,7 @@ public:
         virtual GSM_Error       GetNextToDo(GSM_ToDoEntry *Entry, BOOLEAN start, int *Current, int *Max);
         virtual GSM_Error       AddToDo(GSM_ToDoEntry *Entry);
         virtual GSM_Error       DeleteToDo(GSM_ToDoEntry *Entry);
+        virtual GSM_Error       DeleteAllToDo();
         //sms
         virtual GSM_Error       GetSMSStatus(GSM_SMSStatus *Status);
         virtual GSM_Error       DeleteSMS(GSM_SMSList *List);
