@@ -36,12 +36,9 @@ GSM_Error GSM_Phone_N6510::DeleteCalendar(GSM_CalendarEntry *Entry)
 
 GSM_Error GSM_Phone_N6510::GetNextNote(GSM_NoteEntry *Entry, BOOLEAN start, int *Current, int *Max)
 {
-	return GetNextCalendar3NoteToDo2(Entry, start, Current, Max, &Entry->Location, 0x02, ID_GetNote);
-}
+	if ((*Phones)->Feature("nonote")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
-GSM_Error GSM_Phone_N6510::ReplyAddNote(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
-{
-	return GSM_Return_Error(GSM_ERR_NONE);
+	return GetNextCalendar3NoteToDo2(Entry, start, Current, Max, &Entry->Location, 0x02, ID_GetNote);
 }
 
 GSM_Error GSM_Phone_N6510::AddNote(GSM_NoteEntry *Entry)
@@ -72,6 +69,8 @@ GSM_Error GSM_Phone_N6510::AddNote(GSM_NoteEntry *Entry)
 		0x00,				   	/* note text length		     */
 		0x00,				   	/* phone length/meeting place	   */
 		0x00, 0x00, 0x00};
+
+	if ((*Phones)->Feature("nonote")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 	
 	error=GetFirstCalendarPos3(&Loc,0x02);
 	if (error.Code!=GSM_ERR_NONE) return error;
@@ -94,6 +93,8 @@ GSM_Error GSM_Phone_N6510::DeleteNote(GSM_NoteEntry *Entry)
 {
 	GSM_CalendarEntry Cal;
 
+	if ((*Phones)->Feature("nonote")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+
 	Cal.Location = Entry->Location;
 
 	return DCT34->DeleteCalendar(&Cal);
@@ -101,14 +102,16 @@ GSM_Error GSM_Phone_N6510::DeleteNote(GSM_NoteEntry *Entry)
 
 GSM_Error GSM_Phone_N6510::GetNextToDo(GSM_ToDoEntry *Entry, BOOLEAN start, int *Current, int *Max)
 {
-	if (!(*Phones)->Feature("todo6610")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if ((*Phones)->Feature("todo63")) return GetNextToDo1(Entry, start, Current, Max);
+	if ((*Phones)->Feature("notodo")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	return GetNextCalendar3NoteToDo2(Entry, start, Current, Max, &Entry->Location, 0x01, ID_GetToDo);
 }
 
 GSM_Error GSM_Phone_N6510::AddToDo(GSM_ToDoEntry *Entry)
 {
-	if (!(*Phones)->Feature("todo6610")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if ((*Phones)->Feature("todo63")) return AddToDo1(Entry);
+	if ((*Phones)->Feature("notodo")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	return AddToDo2(Entry);
 }
@@ -117,13 +120,23 @@ GSM_Error GSM_Phone_N6510::DeleteToDo(GSM_ToDoEntry *Entry)
 {
 	GSM_CalendarEntry Cal;
 
-	if (!(*Phones)->Feature("todo6610")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if ((*Phones)->Feature("todo63") || (*Phones)->Feature("notodo")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	Cal.Location = Entry->Location;
 
 	return DCT34->DeleteCalendar(&Cal);
 }
 
+GSM_Error GSM_Phone_N6510::DeleteAllToDo()
+{
+	unsigned char req[] = {NOKIA_FRAME1, 0x11};
+
+	if (!(*Phones)->Feature("todo63")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+
+	(*Debug)->Deb("SENT: Deleting all ToDo\n");
+	return Write(req, sizeof(req), 0x55, 4, ID_DeleteToDo+ID,NULL);
+}
+
 // -------------------------------- method 3 ----------------------------------
 
 
@@ -212,10 +225,9 @@ void GSM_Phone_N6510::FindCalendarDateDifference(GSM_DateTime *DT,long diff)
 
 GSM_Error GSM_Phone_N6510::ReplyGetNextToDo2(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	int			     	Alarm;
+	int			Alarm;
 	GSM_ToDoEntry 		*ToDo = (GSM_ToDoEntry *)S;
 	GSM_ToDoSubEntry 	*Sub;
-	//GSM_DateTime		    	DT;
 
 	(*Debug)->Deb("RECEIVED: todo method 2\n");
 
@@ -436,9 +448,6 @@ GSM_Error GSM_Phone_N6510::PrivGetCalendar3NoteToDo2(void *Entry, int Location,
 	Buff[9] = Location % 256;
 
 	(*Debug)->Deb("SENT: getting calendar note method 3\n");
-//return PrivGetCalendarNoteToDo3(Entry,(*Location),request);
-
-	//ID_GetCalendar
 	return Write(Buff, sizeof(Buff), 0x13, 4, request+ID,Entry);
 }
 
@@ -469,9 +478,7 @@ GSM_Error GSM_Phone_N6510::GetNextCalendar3NoteToDo2(void *Entry, BOOLEAN start,
 
 GSM_Error GSM_Phone_N6510::FindCalendarNoteType3(GSM_CalendarEntry *Entry, int *NoteID)
 {
-//GSM_Calendar_Type NoteType
 	GSM_CalendarEntry	Calendar;
-//	GSM_DateTime	    	DT;
 	GSM_Error	       	error;
 	GSM_Cal_Loc	     	CalendarLocations2;
 	unsigned int		i,j;
@@ -561,12 +568,7 @@ GSM_Error GSM_Phone_N6510::GetFirstCalendarPos3(int *Location,unsigned char type
 	Buff[4] = type;
 	
 	(*Debug)->Deb("SENT: Getting first free calendar/todo/note location\n");
-	return Write(Buff, sizeof(Buff), 0x13, 2, ID_GetFirstCalendarPos+ID, Location);
-}
-
-GSM_Error GSM_Phone_N6510::ReplyAddCalendar3(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
-{
-	return GSM_Return_Error(GSM_ERR_NONE);
+	return Write(Buff, sizeof(Buff), 0x13, 4, ID_GetFirstCalendarPos+ID, Location);
 }
 
 GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
@@ -607,6 +609,8 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
+		SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+
 		switch (SubEntry->GetType()) {
 		case Calendar_Text_Text:
 			Text = SubEntry;
@@ -639,6 +643,8 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 		case Calendar_Int_Repeat_Month:
 			RepeatMonth = SubEntry->GetInt();
 			break;
+		default:
+			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		}
 	}
 
@@ -659,7 +665,7 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 		case Calendar_Type_Call     : req[27]=0x02; break;
 		case Calendar_Type_Birthday : req[27]=0x04; break;
 		case Calendar_Type_Memo     : req[27]=0x08; break;
-		default		     : return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+		default	: return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 	}
 
 	memcpy(&Date,DateStart->GetDateTime(),sizeof(GSM_DateTime));
@@ -755,11 +761,6 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x13, 4, ID_AddCalendar+ID,Entry);
 }
 
-GSM_Error GSM_Phone_N6510::ReplyAddToDo2(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
-{
-	return GSM_Return_Error(GSM_ERR_NONE);
-}
-
 GSM_Error GSM_Phone_N6510::AddToDo2(GSM_ToDoEntry *Entry)
 {
 	int			Loc;
@@ -800,7 +801,8 @@ GSM_Error GSM_Phone_N6510::AddToDo2(GSM_ToDoEntry *Entry)
 	req[9] = Loc%256;
 
 	SubEntry = NULL;
-	while (Entry->GetNext(&SubEntry) == TRUE) {
+	while (Entry->GetNext(&SubEntry)) {
+		SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
 		switch (SubEntry->Type) {
 		case ToDo_Text_Text:
 			Text = SubEntry;
@@ -818,6 +820,8 @@ GSM_Error GSM_Phone_N6510::AddToDo2(GSM_ToDoEntry *Entry)
 		case ToDo_DateTime_SilentAlarm:
 			Alarm = SubEntry;
 			break;
+		default:
+			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		}
 	}
 
@@ -853,8 +857,7 @@ GSM_Error GSM_Phone_N6510::AddToDo2(GSM_ToDoEntry *Entry)
 	req[39]	= DT.Minute;
 
 	if (Alarm != NULL) {
-		if (Alarm->Type == ToDo_DateTime_SilentAlarm)
-		{
+		if (Alarm->Type == ToDo_DateTime_SilentAlarm) {
 			req[22] = 0x00; req[23] = 0x00; req[24] = 0x00; req[25] = 0x00;
 		}
 		timet2   = GSMDateTime2TimeT(&DT);
@@ -880,3 +883,164 @@ GSM_Error GSM_Phone_N6510::AddToDo2(GSM_ToDoEntry *Entry)
 	(*Debug)->Deb("SENT: Adding todo (method 2)\n");
 	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x13, 4, ID_AddToDo+ID,Entry);
 }
+
+// --------------------------- todo 6310/6310i --------------------------------
+
+GSM_Error GSM_Phone_N6510::ReplyGetNextToDo1(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	GSM_ToDoEntry 		*ToDo = (GSM_ToDoEntry *)S;
+	GSM_ToDoSubEntry 	*Sub;
+
+	(*Debug)->Deb("RECEIVED: todo method 1\n");
+
+	ToDo->ClearAll();
+
+	Sub = new GSM_ToDoSubEntry;
+	Sub->Type = ToDo_Priority;
+	switch (msg->Buffer.data()[4]) {
+		case  3: Sub->Priority = GSM_Priority_Low; 	break;
+		case  2: Sub->Priority = GSM_Priority_Medium; 	break;
+		case  1: Sub->Priority = GSM_Priority_High; 	break;
+		default: delete (Sub); return GSM_Return_Error(GSM_ERR_UNKNOWN);
+	}
+	ToDo->AddSubEntry(Sub);
+
+	Sub = new GSM_ToDoSubEntry;
+	Sub->Type = ToDo_Text_Text;
+	Sub->Text.append(NokiaGetUnicodeString(msg->Buffer.data()+14),UnicodeLength(NokiaGetUnicodeString(msg->Buffer.data()+14)));
+	ToDo->AddSubEntry(Sub);
+
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
+GSM_Error GSM_Phone_N6510::GetNextToDo1(GSM_ToDoEntry *Entry, BOOLEAN start, int *Current, int *Max)
+{
+	GSM_Error error;
+	unsigned char Buff[] = {
+			NOKIA_FRAME1,
+			0x03, 0x00, 0x00, 0x80, 0x00,
+			0x00, 0x17};		/* Location */
+
+	if (start) {
+		error = GetToDo1Info();
+		if (error.Code != GSM_ERR_NONE) return error;
+		CurrentCalendarNumber = 0;
+	}
+
+	if (CurrentCalendarNumber >= CalendarLocations.Length) {
+		CalendarLocations.Locations.clear();
+		return GSM_Return_Error(GSM_ERR_EMPTY);
+	}
+
+	Entry->Location = CalendarLocations.Locations.data()[CurrentCalendarNumber];
+
+	CurrentCalendarNumber++;
+
+	*Current = CurrentCalendarNumber;
+	*Max = CalendarLocations.Length;
+
+	Buff[8] = Entry->Location / 256;
+	Buff[9] = Entry->Location % 256;
+
+	(*Debug)->Deb("SENT: getting todo method 1\n");
+	return Write(Buff, sizeof(Buff), 0x55, 4, ID_GetToDo+ID,Entry);
+}
+
+GSM_Error GSM_Phone_N6510::ReplyGetToDoInfo1(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	GSM_Cal_Loc     *CalendarLocations = (GSM_Cal_Loc *)S;
+	int	     	i;
+
+	(*Debug)->Deb("RECEIVED: todo info method 1\n");
+
+	CalendarLocations->Length = msg->Buffer.data()[6]*256+msg->Buffer.data()[7];
+	for (i=0;i<CalendarLocations->Length;i++) {
+		CalendarLocations->Locations.push_back(msg->Buffer.data()[12+(i*4)]*256+msg->Buffer.data()[13+(i*4)]);
+	}
+
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
+GSM_Error GSM_Phone_N6510::GetToDo1Info()
+{
+	unsigned char Buff[] = {
+			NOKIA_FRAME1,
+			0x15, 0x01, 0x00, 0x00,
+			0x00, 0x00, 0x00};
+
+	CalendarLocations.Locations.clear();
+	CalendarLocations.Length = 0;
+
+	(*Debug)->Deb("SENT: getting locations for todo method 1\n");
+	return Write(Buff, sizeof(Buff), 0x55, 4, ID_GetCalendarInfo+ID,&CalendarLocations);
+}
+
+GSM_Error GSM_Phone_N6510::ReplyGetToDo1Location(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	int *Location = (int *)S;
+
+	(*Debug)->Deb("RECEIVED: first free calendar location (method 3) is %i\n",msg->Buffer.data()[8]*256 + msg->Buffer.data()[9]);
+	*Location = msg->Buffer.data()[8]*256 + msg->Buffer.data()[9];
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
+GSM_Error GSM_Phone_N6510::AddToDo1(GSM_ToDoEntry *Entry)
+{
+	int			Loc;
+	unsignedstring	  	Buffer,Buffer2;
+	GSM_ToDoSubEntry    	*SubEntry;
+	GSM_ToDoSubEntry    	*Text = NULL, *Priority = NULL;
+	GSM_Error	       	error;
+	unsigned char 		reqLoc[] 	= {NOKIA_FRAME1, 0x0F};
+	unsigned char 		reqSet[] 	= {
+		NOKIA_FRAME1, 0x01,
+		0x03,		/* Priority */
+		0x01,		/* Length of text */
+		0x80,0x00,
+		0x00,0x00};	/* Location */
+
+	(*Debug)->Deb("SENT: Getting location for ToDo method 1\n");
+	error = Write(reqLoc, sizeof(reqLoc), 0x55, 4, ID_AddToDo+ID,&Loc);
+	if (error.Code!=GSM_ERR_NONE) return error;
+	reqSet[8] = Loc/256;
+	reqSet[9] = Loc%256;
+
+	SubEntry = NULL;
+	while (Entry->GetNext(&SubEntry)) {
+		SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+		switch (SubEntry->Type) {
+		case ToDo_Text_Text:
+			Text = SubEntry;
+			break;
+		case ToDo_Priority:
+			Priority = SubEntry;
+			break;
+		default:
+			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+			break;
+		}
+	}
+
+	if (Priority!=NULL) {
+		switch (Priority->Priority) {
+			case GSM_Priority_Low	: reqSet[4] = 3; break;
+			case GSM_Priority_Medium: reqSet[4] = 2; break;
+			case GSM_Priority_High	: reqSet[4] = 1; break;
+			default: break;
+		}
+	}
+
+	if (Text != NULL) {
+		reqSet[5] = (UnicodeLength(Text->Text.data())+1)%256;
+		NokiaSetUnicodeString(Text->Text.data(),&Buffer);
+	}
+
+	Buffer.push_back(0x00);
+	Buffer.push_back(0x00);
+
+	Buffer2.append((const unsigned char*)reqSet,sizeof(reqSet));
+	Buffer2.append((const unsigned char*)Buffer.data(),Buffer.size());
+
+	(*Debug)->Deb("SENT: Adding todo (method 1)\n");
+	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x55, 4, ID_AddToDo+ID,Entry);
+}
