@@ -1278,7 +1278,7 @@ GSM_Error GSM_Phone_N6510::GetJavaGamesFolderID(wchart *ID, BOOLEAN *NeedSubFold
 	if ((*Phones)->Feature("nofile")==TRUE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	if ((*Phones)->Feature("s40_30")==TRUE) {
-		sprintf(buff,"d:/predefjava/predefgames");
+		sprintf(buff,"d:\\predefjava\\predefgames");
 		ID->clear();
 		ID->append((const wchar_t *)StringToUnicodeReturn(buff),strlen(buff));
 		*NeedSubFolder = FALSE;
@@ -1321,7 +1321,7 @@ GSM_Error GSM_Phone_N6510::GetJavaAppsFolderID(wchart *ID, BOOLEAN *NeedSubFolde
 
 	//series 40 3.0 - filesystem 2
 	if ((*Phones)->Feature("s40_30")==TRUE) {
-		sprintf(buff,"d:/predefjava/predefcollections");
+		sprintf(buff,"d:\\predefjava\\predefcollections");
 		ID->clear();
 		ID->append((const wchar_t *)StringToUnicodeReturn(buff),strlen(buff));
 		*NeedSubFolder = FALSE;
