@@ -1,4 +1,4 @@
-/* (C) 2003 - 2006 by Marcin Wiacek www.mwiacek.com */
+/* (C) 2003 - 2007 by Marcin Wiacek www.mwiacek.com */
 
 #include "../../../../cfg/config.h" //msvc2005
 #include "../../../misc/coding/coding.h"
@@ -36,9 +36,9 @@ if(Ans("\x13",0x03,0x1A,ID_GetCalendar+ID3,&AS))   	return DCT34->ReplyGetNextCa
 if(Ans("\x13",0x03,0x32,ID_GetFirstCalendarPos+ID3,&AS))return DCT34->ReplyGetFirstCalPos1	(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x3B,ID_GetCalendarInfo+ID3,&AS))    return DCT34->ReplyGetCalendarInfo1	(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x41,ID_AddCalendar+ID3,&AS))   	return DCT34->ReplyAddCalendar2		(msg,Debug,(unsigned char *)Struct);
-if(Ans("\x13",0x03,0x66,ID_AddToDo+ID,&AS))   		return ReplyAddToDo2			(msg,Debug,(unsigned char *)Struct);
-if(Ans("\x13",0x03,0x66,ID_AddCalendar+ID,&AS))   	return ReplyAddCalendar3		(msg,Debug,(unsigned char *)Struct);
-if(Ans("\x13",0x03,0x66,ID_AddNote+ID,&AS))   		return ReplyAddNote			(msg,Debug,(unsigned char *)Struct);
+if(Ans("\x13",0x03,0x66,ID_AddToDo+ID,&AS))   		return GSM_Return_Error(GSM_ERR_NONE);
+if(Ans("\x13",0x03,0x66,ID_AddCalendar+ID,&AS))   	return GSM_Return_Error(GSM_ERR_NONE);
+if(Ans("\x13",0x03,0x66,ID_AddNote+ID,&AS))   		return GSM_Return_Error(GSM_ERR_NONE);
 if(Ans("\x13",0x03,0x7E,ID_GetToDo+ID,&AS))    		return ReplyGetNextToDo2 		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x7E,ID_GetCalendar+ID,&AS))    	return ReplyGetNextCalendar3		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x7E,ID_GetNote+ID,&AS))    		return ReplyGetNextNote 		(msg,Debug,(unsigned char *)Struct);
@@ -60,6 +60,12 @@ if(Ans("\x19",0x03,0x0B,ID_GetDateTime+ID,&AS))     	return ReplyGetDateTime			(
 if(Ans("\x1B",0x03,0x01,ID_GetIMEI+ID,&AS))     	return ReplyGetIMEI      		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x1B",0x03,0x0C,ID_GetProductCode+ID,&AS))     	return ReplyGetProductCode		(msg,Debug,(unsigned char *)Struct);
 
+if(Ans("\x55",0x03,0x02,ID_AddToDo+ID,&AS))   		return GSM_Return_Error(GSM_ERR_NONE);
+if(Ans("\x55",0x03,0x04,ID_GetToDo+ID,&AS))   		return ReplyGetNextToDo1		(msg,Debug,(unsigned char *)Struct);
+if(Ans("\x55",0x03,0x10,ID_AddToDo+ID,&AS))   		return ReplyGetToDo1Location		(msg,Debug,(unsigned char *)Struct);
+if(Ans("\x55",0x03,0x12,ID_DeleteToDo+ID,&AS))   	return GSM_Return_Error(GSM_ERR_NONE);
+if(Ans("\x55",0x03,0x16,ID_GetCalendarInfo+ID,&AS))   	return ReplyGetToDoInfo1		(msg,Debug,(unsigned char *)Struct);
+
 //filesystem1
 if(Ans("\x6D",0x03,0x03,ID_AddFilePart+ID,&AS))         return ReplyAddFilePart1		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x6D",0x03,0x05,ID_AddFolder+ID,&AS))         	return ReplyAddFolder1			(msg,Debug,(unsigned char *)Struct);
