@@ -158,6 +158,7 @@ void GSM_Phone_NDCT34::SetFrameID(char *Id)
 
 GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntry *Entry, int *Number, GSM_PBK_Features *Features)
 {
+	GSM_Error	 SetError;
 	GSM_PBKSubEntry	 *SubEntry;
 	unsigned int	 i;
 	int		 Type, Type2, Type3, MaxNum;
@@ -257,6 +258,7 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 		TempBuffer.clear();
 		Type = 0x00;
 		Type3 = NPBK_NOTE;
+		SetError = GSM_Return_Error(GSM_ERR_NONE);
 
 		switch (SubEntry->GetType()) {
 		case PBK_Text_Phone_General:
@@ -268,7 +270,20 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 		case PBK_Text_Phone_Work:
 			if (Type == 0x00) Type = NPBK_NUMBER_WORK; //no break
 		case PBK_Text_Phone_Fax:
-			if (Type == 0x00) Type = NPBK_NUMBER_FAX;
+			if (Type == 0x00) Type = NPBK_NUMBER_FAX; // no break;
+		case PBK_Text_Phone_Video:
+			if (Type == 0x00) Type = NPBK_NUMBER_VIDEO; // no break;
+			Avail = FALSE;
+			for (i=0;i<Features->Numbers.size();i++) {
+				if (Features->Numbers.data()[i] == Type) {
+					Avail = TRUE;
+					break;
+				}
+			}
+			if (!Avail) {
+				SetError = GSM_Return_Error(GSM_ERR_CONVERTED);
+				Type = NPBK_NUMBER_GENERAL;
+			}
 			Type2 = NPBK_NUMBER;
 			Type3 = 0x00;
 			TempBuffer.push_back(Type);
@@ -288,6 +303,7 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 				} else {
 					//check for 7110 and don't allow
 					SubEntry->VoiceTagSetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+					SubEntry->VoiceTagSetError = GSM_Return_Error(GSM_ERR_NONE);
 					TempBuffer.push_back(SubEntry->VoiceTag); //voice tag in dct3
 				}
 			} else {
@@ -309,11 +325,12 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 					}
 				}
 				if (!Avail) {
-					SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+					SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);//it should not happen
 					TempBuffer.clear();
 					break;
 				}
 				if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+				SubEntry->SetError = SetError;
 				Buffer->push_back(Type2);
 				Buffer->push_back(0x00);
 				Buffer->push_back((TempBuffer.size()+6) / 256);
@@ -351,6 +368,16 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			if (Type == 0x00) Type = NPBK_USER_ID; //no break
 		case PBK_Text_Note:
 			if (Type == 0x00) Type = NPBK_NOTE; //no break
+		case PBK_Text_Video_Sharing_SIP:
+			if (Type == 0x00) Type = NPBK_VIDEO_SHARING_SIP; //no break
+		case PBK_Text_Job_Title:
+			if (Type == 0x00) Type = NPBK_JOB_TITLE; //no break
+		case PBK_Text_Name_Formal:
+			if (Type == 0x00) Type = NPBK_NAME_FORMAL; //no break
+		case PBK_Text_Company_Name:
+			if (Type == 0x00) Type = NPBK_COMPANY_NAME; //no break
+		case PBK_Text_Nick_Name:
+			if (Type == 0x00) Type = NPBK_NICK_NAME; //no break
 		case PBK_Text_Name:
 			if (Type == 0x00) {
 				Type = NPBK_NAME; //no break
@@ -375,6 +402,16 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			TempBuffer.push_back(0x00);
 			TempBuffer.push_back(0x00);
 			break;
+		case PBK_DateTime_Birthday:
+			Type2 = NPBK_BIRTHDAY;
+			Type3 = 0x00;
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(SubEntry->GetDateTime()->Year/256);
+			TempBuffer.push_back(SubEntry->GetDateTime()->Year%256);
+			TempBuffer.push_back(SubEntry->GetDateTime()->Month);
+			TempBuffer.push_back(SubEntry->GetDateTime()->Day);
+			TempBuffer.push_back(0x00);
+			break;
 		case PBK_ID_Picture:
 			Type2 = NPBK_PICTURE_ID;
 			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
@@ -439,6 +476,41 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 //			count --;
 //			req[count-5] = 8;
 			break;
+		case PBK_ID_Video_File:
+			Type2 = NPBK_VIDEO_FILE_ID;
+			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+			Avail = FALSE;
+			for (i=0;i<Features->Types.size();i++) {
+				if (Features->Types.data()[i] == Type2) {
+					Avail = TRUE;
+					break;
+				}
+			}
+			if (!Avail) {
+				SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+				TempBuffer.clear();
+				break;
+			}
+			if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(SubEntry->LongValue / (256*256*256));
+			TempBuffer.push_back(SubEntry->LongValue / (256*256));
+			TempBuffer.push_back(SubEntry->LongValue / 256);
+			TempBuffer.push_back(SubEntry->LongValue % 256);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			Buffer->push_back(Type2);
+			Buffer->push_back(0x00);
+			Buffer->push_back((TempBuffer.size()+6) / 256);
+			Buffer->push_back((TempBuffer.size()+6) % 256);
+			Buffer->push_back(++(*Number));
+			Buffer->append((const unsigned char*)TempBuffer.data(),TempBuffer.size());
+			Buffer->push_back(0x01);//difference from normal block
+			TempBuffer.clear();			
+			break;
 		case PBK_ID_Caller_Group:
 			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
 			Avail = FALSE;
@@ -472,7 +544,7 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 		}
 
 		if (TempBuffer.size() != 0) {
-			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+			SubEntry->SetError = SetError;
 			Avail = FALSE;
 			for (i=0;i<Features->Types.size();i++) {
 				if (Features->Types.data()[i] == Type2) {
@@ -483,9 +555,12 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			//we check, if we can convert it to other
 			if (!Avail && Type != 0x00) {
 				Type2 = Type3;
-				if (Features->Types.data()[i] == Type2) {
-					Avail = TRUE;
-					break;
+				for (i=0;i<Features->Types.size();i++) {
+					if (Features->Types.data()[i] == Type2) {
+						Avail = TRUE;
+						SubEntry->SetError = GSM_Return_Error(GSM_ERR_CONVERTED);
+						break;
+					}
 				}
 			}
 			if (!Avail) {
@@ -613,6 +688,7 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 	GSM_PBKSubEntry 	*SubEntry,*PrevSubEntry=NULL;
 	BOOLEAN			Found,LastFirst=FALSE;
 	unsignedint		Nums;
+	GSM_DateTime		DT;
 
 	(*Debug)->Deb("  %i blocks\n",Buffer[0]);
 	for (i=0;i<Buffer[0];i++) {
@@ -646,6 +722,10 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 				Type = PBK_Text_Phone_Fax;
 				(*Debug)->Deb("      Fax number");
 				break;
+			case NPBK_NUMBER_VIDEO:
+				Type = PBK_Text_Phone_Video;
+				(*Debug)->Deb("      Video number");
+				break;
 			default:
 				(*Debug)->Deb("      Unknown number \"%s\"\n",UnicodeToStringReturn(NokiaGetUnicodeString(Buffer+Pos+10)));
 				return GSM_Return_Error(GSM_ERR_UNKNOWN);
@@ -706,6 +786,31 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 				Type = PBK_Text_PTT;
 				(*Debug)->Deb("      Push To Talk");
 			}
+		case NPBK_VIDEO_SHARING_SIP: //no break
+			if (Type == PBK_Not_Assigned) {
+				Type = PBK_Text_Video_Sharing_SIP;
+				(*Debug)->Deb("      Video sharing SIP");
+			}
+		case NPBK_JOB_TITLE: //no break
+			if (Type == PBK_Not_Assigned) {
+				Type = PBK_Text_Job_Title;
+				(*Debug)->Deb("      Job title");
+			}
+		case NPBK_NAME_FORMAL: //no break
+			if (Type == PBK_Not_Assigned) {
+				Type = PBK_Text_Name_Formal;
+				(*Debug)->Deb("      Formal name");
+			}
+		case NPBK_COMPANY_NAME: //no break
+			if (Type == PBK_Not_Assigned) {
+				Type = PBK_Text_Company_Name;
+				(*Debug)->Deb("      Company name");
+			}
+		case NPBK_NICK_NAME: //no break
+			if (Type == PBK_Not_Assigned) {
+				Type = PBK_Text_Nick_Name;
+				(*Debug)->Deb("      NickName");
+			}
 		case NPBK_USER_ID: // no break;
 			if (Type == PBK_Not_Assigned) {
 				Type = PBK_Text_UserID;
@@ -767,6 +872,17 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 			Entry->AddDateTime(PBK_DateTime_Call_Length, *NokiaGetDT(Buffer+Pos+6));
 			Nums.push_back(i);
 			break;
+		case NPBK_BIRTHDAY:
+			(*Debug)->Deb("      Birthday\n");
+			DT.Year = Buffer[Pos+6]*256+Buffer[Pos+7];
+			DT.Month = Buffer[Pos+8];
+			DT.Day = Buffer[Pos+9];
+			DT.Hour = 0;
+			DT.Minute = 0;
+			DT.Second = 0;
+			Entry->AddDateTime(PBK_DateTime_Call_Length, DT);
+			Nums.push_back(i);
+			break;
 		case NPBK_CALL_LENGTH:
 			(*Debug)->Deb("      Call length\n");
 			Found = FALSE;
@@ -808,6 +924,7 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 				case PBK_Text_Phone_Home:
 				case PBK_Text_Phone_Work:
 				case PBK_Text_Phone_Fax:
+				case PBK_Text_Phone_Video:
 					j++;
 					break;
 				default:
@@ -824,6 +941,11 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 			Entry->AddLong(PBK_ID_Picture, Buffer[Pos+8]*256*256*256+Buffer[Pos+9]*256*256+Buffer[Pos+10]*256+Buffer[Pos+11]);
 			Nums.push_back(i);
 			break;
+		case NPBK_VIDEO_FILE_ID:
+			(*Debug)->Deb("      Video file ID\n");
+			Entry->AddLong(PBK_ID_Video_File, Buffer[Pos+8]*256*256*256+Buffer[Pos+9]*256*256+Buffer[Pos+10]*256+Buffer[Pos+11]);
+			Nums.push_back(i);
+			break;
 		case NPBK_RINGTONE_ID:
 			(*Debug)->Deb("      Ringtone ID\n");
 			Entry->AddLong(PBK_ID_Ringtone, Buffer[Pos+7]);
@@ -910,6 +1032,12 @@ GSM_Error GSM_Phone_NDCT34::ReplyGetPBKFeatures(GSM_Protocol_Message *msg, Debug
 		Entry->Types.push_back(msg->Buffer.data()[pos+4]);
 		pos+=msg->Buffer.data()[pos+3];
 	}
+
+	Entry->Numbers.clear();
+	for (i=0;i<msg->Buffer.data()[pos+4];i++) {
+		Entry->Numbers.push_back(msg->Buffer.data()[pos+5+i]);
+	}
+
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
@@ -1141,7 +1269,7 @@ GSM_Error GSM_Phone_NDCT34::ReplyGetNextCalendar1(GSM_Protocol_Message *msg, Deb
 
 GSM_Error GSM_Phone_NDCT34::GetNextCalendar1(GSM_CalendarEntry *Entry, BOOLEAN start, int *Current, int *Max)
 {
-	GSM_Error	       error;
+	GSM_Error	   error;
 	unsigned char	   Buff[] = {
 		NOKIA_FRAME1, 0x19,
 		0x00, 0x00};	    // location
@@ -1208,6 +1336,7 @@ GSM_Error GSM_Phone_NDCT34::AddCalendar1(GSM_CalendarEntry *Entry)
 
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
+		SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
 		switch (SubEntry->GetType()) {
 		case Calendar_Text_Text:
 			Text = SubEntry;
@@ -1237,6 +1366,8 @@ GSM_Error GSM_Phone_NDCT34::AddCalendar1(GSM_CalendarEntry *Entry)
 		case Calendar_Int_Repeat_Month:
 			SubEntry->GetInt();
 			break;
+		default:
+			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		}
 	}
 
@@ -1385,14 +1516,14 @@ GSM_Error GSM_Phone_NDCT34::ReplyAddCalendar2(GSM_Protocol_Message *msg, DebugIn
 
 GSM_Error GSM_Phone_NDCT34::AddCalendar2(GSM_CalendarEntry *Entry)
 {
-	GSM_DateTime	    Date,Date2;
-	time_t		  timet1, timet2;
-	unsignedstring	  Buffer,Buffer2;
+	GSM_DateTime	    	Date,Date2;
+	time_t		  	timet1, timet2;
+	unsignedstring	  	Buffer,Buffer2;
 	GSM_CalendarSubEntry    *SubEntry, *Text = NULL, *Location = NULL;
 	GSM_CalendarSubEntry    *Phone = NULL, *DateStart = NULL, *Alarm = NULL;
-	unsigned int	    diff;
-	GSM_Error	       error;
-	unsigned char	   Buff[2];
+	unsigned int	    	diff;
+	GSM_Error	      	error;
+	unsigned char	   	Buff[2];
 
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
@@ -1621,8 +1752,8 @@ GSM_Error GSM_Phone_NDCT34::DeleteCalendar(GSM_CalendarEntry *Entry)
 
 wchar_t *NokiaGetUnicodeString(const unsigned char *Buffer)
 {
-	static	  wchar_t dst[500];
-	int	     pos=0;
+	static	  	wchar_t dst[500];
+	int	     	pos=0;
 
 	while (Buffer[pos*2] != 0 || Buffer[pos*2+1] != 0) {
 		dst[pos] = Buffer[pos*2] * 256 + Buffer[pos*2+1];
@@ -1634,8 +1765,8 @@ wchar_t *NokiaGetUnicodeString(const unsigned char *Buffer)
 
 wchar_t *NokiaGetUnicodeSimple(const unsigned char *Buffer, int Len)
 {
-	static	  wchar_t dst[5000];
-	int	     i;
+	static	  	wchar_t dst[5000];
+	int	     	i;
 
 	for (i=0;i<Len;i++) {
 		dst[i] = Buffer[i*2] * 256 + Buffer[i*2+1];
@@ -1674,11 +1805,11 @@ GSM_DateTime *NokiaGetDT(const unsigned char *Buffer)
 // gets Recurrance/Repeat info from frame into Calendar structure
 GSM_Error NokiaGetCalendarRecurranceRepeat(DebugInfo *Debug, GSM_CalendarEntry *Entry, const unsigned char *Buffer, const unsigned char *RepeatBuffer)
 {
-	time_t		  timet;
-	struct tm	       tmstruct;
-	int		     i, Repeat, Recurrance = Buffer[0]*256 + Buffer[1];
+	time_t		  	timet;
+	struct tm	       	tmstruct;
+	int		     	i, Repeat, Recurrance = Buffer[0]*256 + Buffer[1];
 	GSM_CalendarSubEntry    *SubEntry;
-	GSM_DateTime	    DT;
+	GSM_DateTime	    	DT;
 
 	if (Recurrance == 0) return GSM_Return_Error(GSM_ERR_NONE);
 	Debug->Deb("Recurrance : %i hours\n",Recurrance);
