@@ -10,12 +10,16 @@ class GSM_Protocol_PHONET:virtual public GSM_Protocol
 {
 public:
         GSM_Protocol_PHONET(GSM_Device **Dev, DebugInfo **Deb):GSM_Protocol(Dev,Deb) {
+#ifdef WIN32
 		Info.push_back(GSM_Protocol_Info("serial",   "dku2phonet",  false, true));
 		Info.push_back(GSM_Protocol_Info("serial",   "dku2", 	    false, false));
 		Info.push_back(GSM_Protocol_Info("serial",   "phonetblue",  false, true));
 		Info.push_back(GSM_Protocol_Info("bluetooth","bluephonet",  false, true));
 		Info.push_back(GSM_Protocol_Info("bluetooth","bluerfphonet",false, true));
-		Info.push_back(GSM_Protocol_Info("infrared", "irdaphonet",  true, false));
+		Info.push_back(GSM_Protocol_Info("infrared", "irdaphonet",  true,  false));
+#else
+		Info.push_back(GSM_Protocol_Info("infrared", "irdaphonet",  true,  true));
+#endif
         }
         ~GSM_Protocol_PHONET() {
         }
