@@ -113,6 +113,7 @@ GSM_Error GSM_Backup::SavePbkToTextFile(FILE *file)
 			case PBK_Text_Phone_Home     : sprintf(buff2,"NumberHome"); 	break;
 			case PBK_Text_Phone_Work     : sprintf(buff2,"NumberWork"); 	break;
 			case PBK_Text_Phone_Fax      : sprintf(buff2,"NumberFax"); 	break;
+			case PBK_Text_Phone_Video    : sprintf(buff2,"NumberVideo"); 	break;
 			case PBK_Text_Postal	     : sprintf(buff2,"Address"); 	break;
 			case PBK_Text_Postal_City    : sprintf(buff2,"City"); 		break;
 			case PBK_Text_Postal_State   : sprintf(buff2,"State"); 		break;
@@ -127,9 +128,16 @@ GSM_Error GSM_Backup::SavePbkToTextFile(FILE *file)
 			case PBK_Text_Name_Last	     : sprintf(buff2,"LastName"); 	break;
 			case PBK_Text_Name_First     : sprintf(buff2,"FirstName"); 	break;
 			case PBK_Text_PTT            : sprintf(buff2,"PTT"); 		break;
+			case PBK_Text_Name_Formal    : sprintf(buff2,"FormalName"); 	break;
+			case PBK_Text_Video_Sharing_SIP: sprintf(buff2,"VideoSIP"); 	break;
+			case PBK_Text_Job_Title      : sprintf(buff2,"JobTitle"); 	break;
+			case PBK_Text_Company_Name   : sprintf(buff2,"CompanyName"); 	break;
+			case PBK_Text_Nick_Name      : sprintf(buff2,"NickName"); 	break;
 			case PBK_Bool_PTT_Subscribed : sprintf(buff2,"PTTSubscribed"); 	break;
 			case PBK_ID_Caller_Group     : sprintf(buff2,"CallerGroup");	break;
 			case PBK_ID_Picture          : sprintf(buff2,"PictureID");	break;
+			case PBK_ID_Video_File       : sprintf(buff2,"VideoFileID");	break;
+			case PBK_DateTime_Birthday   : sprintf(buff2,"Birthday");       break;
 			default			     : break;
 			}
 			if (buff2[0] == 0) continue;
@@ -147,6 +155,12 @@ GSM_Error GSM_Backup::SavePbkToTextFile(FILE *file)
 			SaveTextFilePart(StringToUnicodeReturn(buff2), file, TRUE);
 
 			switch (PBKSubEntry->GetType()) {
+			case PBK_DateTime_Birthday:
+				sprintf(buff,"Entry%02iValue = ",Num2);
+				SaveTextFilePart(StringToUnicodeReturn(buff), file, FALSE);
+				SaveVCalendarDateTime(PBKSubEntry->GetDateTime(),buff);
+				SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
+				break;
 			case PBK_Bool_PTT_Subscribed:
 				if (PBKSubEntry->BoolValue) {
 					sprintf(buff,"Entry%02iValue = yes",Num2);
@@ -174,6 +188,7 @@ GSM_Error GSM_Backup::SavePbkToTextFile(FILE *file)
 			case PBK_Text_Phone_Home:
 			case PBK_Text_Phone_Work:
 			case PBK_Text_Phone_Fax:
+			case PBK_Text_Phone_Video:
 				if (PBKSubEntry->VoiceTag!=-1) {
 					sprintf(buff,"Entry%02iVoiceTag = %i",Num2,PBKSubEntry->VoiceTag);
 					SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
@@ -390,7 +405,7 @@ GSM_Error GSM_Backup::SaveToTextFile(char *FileName)
 	SaveTextFilePart(StringToUnicodeReturn(""), file, TRUE);
 
 	SaveTextFilePart(StringToUnicodeReturn("[Backup]"), file, TRUE);
-	SaveTextFilePart(StringToUnicodeReturn("Format=1.05"), file, TRUE);
+	SaveTextFilePart(StringToUnicodeReturn("Format = 1.05"), file, TRUE);
 
 	sprintf(buff,"IMEI = \"%s\"",DeviceIMEI);
 	SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
@@ -442,6 +457,7 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 	int			i;
 	BOOLEAN			Found;
 	wchart			Txt;
+	GSM_DateTime		DT;
 
 	StringToUnicode("PhonePBK",x);
 	Section = NULL;
@@ -466,6 +482,7 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 			else if (!wcscmp(value,StringToUnicodeReturn("NumberHome"))) 	PBKType = PBK_Text_Phone_Home;
 			else if (!wcscmp(value,StringToUnicodeReturn("NumberWork"))) 	PBKType = PBK_Text_Phone_Work;
 			else if (!wcscmp(value,StringToUnicodeReturn("NumberFax"))) 	PBKType = PBK_Text_Phone_Fax;
+			else if (!wcscmp(value,StringToUnicodeReturn("NumberVideo"))) 	PBKType = PBK_Text_Phone_Video;
 			else if (!wcscmp(value,StringToUnicodeReturn("NumberGeneral"))) PBKType = PBK_Text_Phone_General;
 			else if (!wcscmp(value,StringToUnicodeReturn("Address"))) 	PBKType = PBK_Text_Postal;
 			else if (!wcscmp(value,StringToUnicodeReturn("City"))) 		PBKType = PBK_Text_Postal_City;
@@ -478,11 +495,28 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 			else if (!wcscmp(value,StringToUnicodeReturn("UserID"))) 	PBKType = PBK_Text_UserID;
 			else if (!wcscmp(value,StringToUnicodeReturn("Note"))) 		PBKType = PBK_Text_Note;
 			else if (!wcscmp(value,StringToUnicodeReturn("PTT"))) 		PBKType = PBK_Text_PTT;
+			else if (!wcscmp(value,StringToUnicodeReturn("FormalName"))) 	PBKType = PBK_Text_Name_Formal;
+			else if (!wcscmp(value,StringToUnicodeReturn("VideoSIP"))) 	PBKType = PBK_Text_Video_Sharing_SIP;
+			else if (!wcscmp(value,StringToUnicodeReturn("JobTitle"))) 	PBKType = PBK_Text_Job_Title;
+			else if (!wcscmp(value,StringToUnicodeReturn("CompanyName"))) 	PBKType = PBK_Text_Company_Name;
+			else if (!wcscmp(value,StringToUnicodeReturn("NickName"))) 	PBKType = PBK_Text_Nick_Name;
+
 			if (PBKType == PBK_Not_Assigned) {
 				if (!wcscmp(value,StringToUnicodeReturn("CallerGroup"))) 	PBKType = PBK_ID_Caller_Group;
+				else if (!wcscmp(value,StringToUnicodeReturn("VideoFileID"))) 	PBKType = PBK_ID_Video_File;
 				else if (!wcscmp(value,StringToUnicodeReturn("PictureID"))) 	PBKType = PBK_ID_Picture;
 
-				if (PBKType == PBK_Not_Assigned) continue;
+				if (PBKType == PBK_Not_Assigned) {
+					if (!wcscmp(value,StringToUnicodeReturn("Birthday"))) 	PBKType = PBK_DateTime_Birthday;
+					if (PBKType == PBK_Not_Assigned) continue;
+
+					sprintf(x2,"Entry%02iValue",i);
+					value = File->GetValueInSection(Section,StringToUnicodeReturn(x2));
+					if (value == NULL) continue;
+
+					if (!ReadVCalendarDateTime(UnicodeToStringReturn(value), &DT)) continue;
+					PBKEntry->AddDateTime(PBKType,DT);
+				}
 
 				sprintf(x2,"Entry%02iNumber",i);
 				value = File->GetValueInSection(Section,StringToUnicodeReturn(x2));
@@ -506,6 +540,7 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 			    PBKType == PBK_Text_Phone_Home ||
 			    PBKType == PBK_Text_Phone_Work ||
 			    PBKType == PBK_Text_Phone_Fax ||
+			    PBKType == PBK_Text_Phone_Video ||
 			    PBKType == PBK_Text_Phone_General) {
 				sprintf(x2,"Entry%02iVoiceTag",i);
 				value = File->GetValueInSection(Section,StringToUnicodeReturn(x2));
