@@ -337,6 +337,7 @@ GSM_Backup::GSM_Backup()
 	ToDo = NULL;
 	Notes = NULL;
 
+	FileMD5Original[0] = 0;
 	DeviceIMEI[0]=0;
 	DeviceModel[0]=0;
 	FileCreator[0]=0;
@@ -605,6 +606,7 @@ void GSM_Backup::DeletePointersFromPBK()
 	GSM_Backup_PBKEntry	*PBKEntry=NULL,*PBK2=NULL,*PBKEntry2,*Entry2;
 	GSM_PBKSubEntry 	*SubEntry;
 	GSM_PBKEntry 		*En;
+	GSM_DateTime		DT;
 
 	while (GetNext_PBK(&PBKEntry)) {
 		SubEntry = NULL;
@@ -612,12 +614,16 @@ void GSM_Backup::DeletePointersFromPBK()
 		while (PBKEntry->GetEntry()->GetNext(&SubEntry)) {
 			switch (SubEntry->GetType()) {
 			case PBK_DateTime_Call_Length:
-				break; //not required for this memory
+			case PBK_DateTime_Birthday:
+				memcpy(&DT,SubEntry->GetDateTime(),sizeof(GSM_DateTime));
+				En->AddDateTime(SubEntry->GetType(),DT);
+				break;
 			case PBK_ID_Caller_Group:
 				En->AddLong(SubEntry->GetType(),SubEntry->LongValue);
 				break;
 			case PBK_ID_Picture:
 			case PBK_ID_Ringtone:
+			case PBK_ID_Video_File:
 				break; //we delete them
 			case PBK_Bool_PTT_Subscribed:
 				En->AddBool(SubEntry->GetType(),SubEntry->BoolValue);
@@ -654,6 +660,7 @@ void GSM_Backup::DeleteCallerFromPBK()
 	GSM_Backup_PBKEntry	*PBKEntry=NULL,*PBK2=NULL,*PBKEntry2,*Entry2;
 	GSM_PBKSubEntry 	*SubEntry,*SubEntry2;
 	GSM_PBKEntry 		*En;
+	GSM_DateTime		DT;
 
 	while (GetNext_PBK(&PBKEntry)) {
 		SubEntry = NULL;
@@ -661,12 +668,16 @@ void GSM_Backup::DeleteCallerFromPBK()
 		while (PBKEntry->GetEntry()->GetNext(&SubEntry)) {
 			switch (SubEntry->GetType()) {
 			case PBK_DateTime_Call_Length:
-				break; //not required for this memory
+			case PBK_DateTime_Birthday:
+				memcpy(&DT,SubEntry->GetDateTime(),sizeof(GSM_DateTime));
+				En->AddDateTime(SubEntry->GetType(),DT);
+				break;
 			case PBK_ID_Caller_Group:
 				//we delete it
 				break;
 			case PBK_ID_Picture:
 			case PBK_ID_Ringtone:
+			case PBK_ID_Video_File:
 				En->AddLong(SubEntry->GetType(),SubEntry->LongValue);
 				break;
 			case PBK_Bool_PTT_Subscribed:
