@@ -5,8 +5,9 @@
 #endif
 
 #include "../../misc/files.h"
-#include "../sms/gsmsms.h"
 #include "../../misc/misc.h"
+#include "../sms/gsmsms.h"
+#include "../sms/smsmulti.h"
 #include "../gsmmisc.h"
 #include "../gsmpbk.h"
 #include "../gsmcal.h"
@@ -18,6 +19,7 @@
 typedef struct {
 	BOOLEAN PhonePBK;
 	BOOLEAN PhonePBKPointers;
+	BOOLEAN PhonePBKCallers;
 	BOOLEAN SIMPBK;
 	BOOLEAN Calendar;
 	BOOLEAN Notes;
@@ -183,6 +185,8 @@ public:
         void                    Delete_JAD();
         void                    Delete_Notes();
         void                    Delete_ToDo();
+	void 			DeleteCallerFromPBK();
+	void 			DeletePointersFromPBK();
 private:
         GSM_Backup_PBKEntry     *PBK;
         GSM_Backup_CalEntry     *Cal;
