@@ -531,11 +531,8 @@ void GetMemory(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[]
 			case PBK_Text_Phone_Fax:
 				printf("Fax number \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
 				break;
-			case PBK_Text_Email:
-				printf("Email \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
-				break;
-			case PBK_Text_URL:
-				printf("URL \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+			case PBK_Text_Phone_Video:
+				printf("Video number \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
 				break;
 			case PBK_Text_Postal:
 				printf("Postal address \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
@@ -555,6 +552,12 @@ void GetMemory(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[]
 			case PBK_Text_Postal_Country:
 				printf("Country \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
 				break;
+			case PBK_Text_Email:
+				printf("Email \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_URL:
+				printf("URL \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
 			case PBK_Text_UserID:
 				printf("User ID \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
 				break;
@@ -564,6 +567,30 @@ void GetMemory(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[]
 			case PBK_Text_Name:
 				printf("Name \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
 				break;
+			case PBK_Text_Name_Last:
+				printf("Last name \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Name_First:
+				printf("First name \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Name_Formal:
+				printf("Formal name \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Company_Name:
+				printf("Company name \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Nick_Name:
+				printf("Nickname \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_PTT:
+				printf("PTT \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Video_Sharing_SIP:
+				printf("Video SIP \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Job_Title:
+				printf("Job title \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
 			case PBK_DateTime_Call_Length:
 				printf("Date & time %02i:%02i:%02i %02i-%02i-%04i",
 					SubEntry->GetDateTime()->Hour,
@@ -573,6 +600,27 @@ void GetMemory(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[]
 					SubEntry->GetDateTime()->Month,
 					SubEntry->GetDateTime()->Year);
 				break;
+			case PBK_DateTime_Birthday:
+				printf("Birthday %02i-%02i-%04i",
+					SubEntry->GetDateTime()->Day,
+					SubEntry->GetDateTime()->Month,
+					SubEntry->GetDateTime()->Year);
+				break;
+			case PBK_ID_Caller_Group:
+				printf("Caller group \"%i\"",SubEntry->LongValue);
+				break;
+			case PBK_ID_Picture:
+				printf("Picture ID \"%i\"",SubEntry->LongValue);
+				break;
+			case PBK_ID_Ringtone:
+				printf("Ringtone ID \"%i\"",SubEntry->LongValue);
+				break;
+			case PBK_ID_Video_File:
+				printf("Video file ID \"%i\"",SubEntry->LongValue);
+				break;
+			case PBK_Bool_PTT_Subscribed:
+//				printf(" \"%i\"",SubEntry->GetLongValue());
+				break;
 			}
 			if (SubEntry->CallLength != -1) {
 				printf(" (length %i:%i:%i)",SubEntry->CallLength/(60*60),SubEntry->CallLength/60,SubEntry->CallLength%60);
