@@ -50,7 +50,7 @@ class CfgDlg : public wxDialog
 		DECLARE_EVENT_TABLE();
 		
 	public:
-		CfgDlg(wxWindow *parent, wxWindowID id = 1, const wxString &title = wxT("Untitled1"), const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = CfgDlg_STYLE);
+		CfgDlg(GSM_GPlusConfig *CFG2, GSM_StateMachine *s2, wxWindow *parent, wxWindowID id = 1, const wxString &title = wxT("Untitled1"), const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = CfgDlg_STYLE);
 		virtual ~CfgDlg();
 	
 	private:
@@ -58,6 +58,14 @@ class CfgDlg : public wxDialog
                 //GUI Control Declaration Start and GUI Control Declaration End.
 		//wxDev-C++ will remove them. Add custom code after the block.
 		////GUI Control Declaration Start
+		wxStaticText *WxStaticText7;
+		wxStaticText *WxStaticText6;
+		wxStaticText *WxStaticText5;
+		wxTextCtrl *WxEdit3;
+		wxButton *WxButton1;
+		wxTextCtrl *WxEdit2;
+		wxComboBox *WxComboBox3;
+		wxStaticText *WxStaticText4;
 		wxCheckBox *WxCheckBox3;
 		wxCheckBox *WxCheckBox2;
 		wxComboBox *WxComboBox1;
@@ -80,6 +88,14 @@ class CfgDlg : public wxDialog
 		enum
 		{
 			////GUI Enum Control ID Start
+			ID_WXSTATICTEXT7 = 1025,
+			ID_WXSTATICTEXT6 = 1024,
+			ID_WXSTATICTEXT5 = 1023,
+			ID_WXEDIT3 = 1022,
+			ID_WXBUTTON1 = 1021,
+			ID_WXEDIT2 = 1020,
+			ID_WXCOMBOBOX3 = 1019,
+			ID_WXSTATICTEXT4 = 1018,
 			ID_WXCHECKBOX3 = 1017,
 			ID_WXCHECKBOX2 = 1016,
 			ID_WXCOMBOBOX1 = 1013,
@@ -99,6 +115,9 @@ class CfgDlg : public wxDialog
             void SetConfig(GSM_GPlusConfig *CFG2, GSM_StateMachine *s2);
     		void WxComboBox1Selected(wxCommandEvent& event );
     		void WxComboBox2Selected(wxCommandEvent& event );
+		void WxButton1Click(wxCommandEvent& event);
+		void WxComboBox3Selected(wxCommandEvent& event );
+		void WxEdit2Updated(wxCommandEvent& event);
 	
 	private:
 		void OnClose(wxCloseEvent& event);
@@ -109,10 +128,13 @@ class CfgDlg : public wxDialog
 		void WxChoice1Selected(wxCommandEvent& event );
 		void WxButton2Click(wxCommandEvent& event);
 		void WxButton3Click(wxCommandEvent& event);
+        void SelectSet();
+        void SaveSet();
 
-        GSM_StateMachine *s;
-        GSM_GPlusConfig *CFG;
-            
+        int                 Number;		
+        bool                EditMode;
+        GSM_StateMachine    *s;
+        GSM_GPlusConfig     *CFG;          
 };
 
 #endif
